@@ -5,7 +5,7 @@ use warnings;
 use Dancer2::Plugin;
 use Dancer2::Plugin::Cart::InlineViews;
 use JSON;
-our $VERSION = '0.0004';  #Version
+our $VERSION = '0.0005';  #Version
 
 
 BEGIN{
@@ -599,7 +599,7 @@ Dancer2::Plugin::Cart - Cart interface for Dancer2 applications
 
 =head1 VERSION
 
-version 0.0004
+version 0.0005
 
 =head1 SYNOPSIS
 
@@ -699,13 +699,16 @@ Add status 1 to the ec_cart structure.
 
 Add defautl adjustments to the ec_cart structure. The default adjustments are:  Discounts, Shipping, Taxes.
 
+=head1 AUTHORS
+
+=head2 CORE DEVELOPERS
+
+    Andrew Baerg
+    Ruben Amortegui
+
 =head1 AUTHOR
 
-YourSole Core Developers
-
-=head1 DEVELOPERS
-
-Ruben Amortegui <ruben.amortegui@gmail.com>
+    YourSole Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
